DROP TRIGGER IF EXISTS "notifyCronDaemon" ON public.esia_cron_plugin;

CREATE TRIGGER "notifyCronDaemon"
    AFTER INSERT OR UPDATE OF cron_interval, cron_log_file, cron_retries, cron_retries_interval, cron_parameter
    ON public.esia_cron_plugin
    FOR EACH ROW
    EXECUTE FUNCTION public.trigger_notify_servicecron();

-- Issue #1438
UPDATE esia_configuration SET config_value='\S*LOAD' WHERE config_key='SRV_CPU_LOAD';
UPDATE esia_configuration SET config_value='\S*(MEM|RAM)$' WHERE config_key='SRV_RAM_LOAD';
UPDATE esia_configuration SET config_value='\S*STORAGE' WHERE config_key='SRV_HDD_LOAD';
UPDATE esia_configuration SET config_value='\S*INTERFACE%' WHERE config_key='SRV_INT_LOAD';

CREATE OR REPLACE VIEW public.view_node_state
 AS
 SELECT t2.device_id,
    COALESCE(t2.warning, 0::bigint) AS warning,
    COALESCE(t2.critical, 0::bigint) AS critical,
    COALESCE(t2.unknown, 0::bigint) AS unknown,
    COALESCE(t2.ok, 0::bigint) AS ok,
    COALESCE(t2.maintenance, 0::bigint) AS maintenance,
    COALESCE(t2.acq, 0::bigint) AS acq
   FROM crosstab('SELECT device_id::integer as rowid,error_type::text as attribute,nbr::bigint
		FROM	(SELECT device_id,error_type,count (*) as nbr
					FROM esia_device
					JOIN esia_error_happen ON happen_device_id = device_id
				    JOIN esia_errors ON error_id = happen_error_id
					WHERE device_delete=false AND happen_acquitte=0
					GROUP BY device_id,error_type
			UNION
			SELECT service_device_id,''ok'',count(*) AS nbr
			FROM esia_services
			WHERE service_previous_state = 0
				AND service_delete = false
			GROUP BY service_device_id
			UNION
			SELECT service_device_id,''acq'',count(*) AS nbr
			FROM esia_services
			WHERE service_last_stdout IS NOT NULL AND service_previous_state <>0 AND service_id NOT IN (SELECT happen_service_id FROM view_actual_error)
				AND service_delete = false
			GROUP BY service_device_id

		) AS T2
		ORDER BY 1,2'::text, 'SELECT * FROM (SELECT error_type FROM  esia_errors UNION SELECT ''ok'' UNION SELECT ''acq'') AS T1 ORDER BY 1;'::text) t2(device_id integer, acq bigint, critical bigint, maintenance bigint, ok bigint, unknown bigint, warning bigint);

ALTER TABLE public.view_node_state OWNER TO esia;

CREATE OR REPLACE FUNCTION public.getnodesstate(
	userid integer)
    RETURNS TABLE(typerror character varying, nbr bigint)
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE PARALLEL UNSAFE
    ROWS 1000

AS $BODY$
DECLARE

BEGIN
--CREATE TEMP TABLE userNode AS SELECT * FROM view_node_state WHERE device_id IN ( SELECT * FROM getUserAccessNode(userid));
RETURN QUERY  WITH userNode AS (
	SELECT device_id,warning,critical,unknown,ok,maintenance,acq
	FROM view_node_state
	WHERE device_id IN ( SELECT * FROM getUserAccessNode(userid))
	)
SELECT 'ok'::varchar,count(*)::integer
FROM userNode
WHERE warning=0 AND critical=0 AND unknown=0 AND ok > 0
UNION
SELECT 'critical',count(*) FROM userNode
WHERE critical>0
UNION
SELECT 'warning',count(*) FROM userNode
WHERE critical=0 AND warning>0
UNION
SELECT 'unknown',count(*) FROM userNode
WHERE critical=0 AND warning=0 AND unknown>0;

END;
$BODY$;

ALTER FUNCTION public.getnodesstate(integer) OWNER TO esia;

DROP INDEX IF EXISTS public.happen_index_acquitte;
CREATE INDEX IF NOT EXISTS happen_index_acquitte ON public.esia_error_happen USING btree (happen_acquitte) WHERE happen_acquitte=0;

UPDATE esia_configuration SET config_description = REGEXP_REPLACE(config_description,'\%error\.time => date de l''erreur','%error.starttime => date de début de l''erreur <br />
%error.time => date fin de l''erreur<br />')
WHERE config_key='MAIL_FORMAT_MESSAGE' AND MD5(config_description)IN('b271cdd8ddca1aa451190ed193080ac2');

UPDATE esia_configuration SET config_value =  REGEXP_REPLACE(config_value,'\%error\.time</p>','%error.starttime</p></td><td></td></tr>
 <tr valign="top">
                                <td></td>
                                <td style="width:120px; padding-right:10px; padding-bottom:22px;">
                                    <p style="margin:0;">Date fin de l''erreur :</p>
                                </td>
                                <td style="padding-bottom:22px;">
                                    <p style="margin:0;">%error.time</p>

 ')
WHERE config_key='MAIL_FORMAT_MESSAGE' AND MD5(config_value)IN('8a76fdfcf17ff8392436950b1ea6ab82','3befb89bf0f927ed9a4fa86f45c29102','0677ab1b321fad5161e6506bbfc1d1ce');

CREATE INDEX happen_idx_timestamp_error
    ON public.esia_error_happen USING btree
    (happen_timestamp DESC NULLS FIRST)
    WITH (deduplicate_items=True);
