CREATE TABLE IF NOT EXISTS device_tab
(
    tab_id serial,
    tab_name character varying(50) COLLATE pg_catalog."default",
    tab_default_options json,
    tab_url character varying(200) COLLATE pg_catalog."default",
    tab_order smallint DEFAULT 99,
    tab_web_id integer,
    CONSTRAINT tab_primary_key PRIMARY KEY (tab_id),
    CONSTRAINT tab_name_unique UNIQUE (tab_name),
    CONSTRAINT "tab_foreignKey_web_plugin" FOREIGN KEY (tab_web_id)
        REFERENCES public.esia_web_plugin (web_id) MATCH FULL
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
);

ALTER TABLE IF EXISTS device_tab OWNER to esia;


CREATE TABLE IF NOT EXISTS public.device_tab_linked
(
    tab_linked_device_id bigint NOT NULL,
    tab_linked_tab_id integer NOT NULL,
    tab_linked_order smallint,
    tab_linked_option json,
    CONSTRAINT "linked_primaryKey" PRIMARY KEY (tab_linked_device_id, tab_linked_tab_id),
    CONSTRAINT "linked_foreignKey_device_id" FOREIGN KEY (tab_linked_device_id)
        REFERENCES public.esia_device (device_id) MATCH FULL
        ON UPDATE NO ACTION
        ON DELETE NO ACTION,
    CONSTRAINT "linked_foreignKey_device_tab" FOREIGN KEY (tab_linked_tab_id)
        REFERENCES public.device_tab (tab_id) MATCH FULL
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
);

ALTER TABLE IF EXISTS public.device_tab_linked OWNER to esia;

-- FUNCTION: public.trigger_notify_serviceCron()

-- DROP FUNCTION IF EXISTS public.trigger_notify_serviceCron();
ALTER TABLE esia_plugins ADD COLUMN plugin_cron_type character varying(10);
ALTER TABLE esia_plugins ADD COLUMN plugin_cron_only_existing boolean;

CREATE TABLE IF NOT EXISTS public.esia_cron_plugin
(
    cron_id bigserial,
    cron_plugin_id integer NOT NULL,
    cron_interval interval,
    cron_status character varying(10) COLLATE pg_catalog."default",
    cron_last_exec timestamp with time zone,
    cron_next_exec timestamp with time zone,
    cron_log_file character varying(200) COLLATE pg_catalog."default",
    cron_retries integer NOT NULL DEFAULT 1,
    cron_retries_interval interval,
    cron_parameter character varying(200) COLLATE pg_catalog."default",
    cron_delete boolean DEFAULT false,
    CONSTRAINT "cron_primaryKey" PRIMARY KEY (cron_id),
    CONSTRAINT "cron_foreignKey_plugin_id" FOREIGN KEY (cron_plugin_id)
        REFERENCES public.esia_plugins (plugin_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
);
CREATE TABLE IF NOT EXISTS public.esia_cron_error
(
    cron_error_id bigserial,
    cron_id bigint NOT NULL,
    cron_date timestamp without time zone NOT NULL,
    cron_logfile character varying(200) COLLATE pg_catalog."default",
    cron_delete boolean DEFAULT false,
    CONSTRAINT esia_cron_error_pkey PRIMARY KEY (cron_error_id),
    CONSTRAINT "cron_error_foreignKey_cron_id" FOREIGN KEY (cron_id)
        REFERENCES public.esia_cron_plugin (cron_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
);

ALTER TABLE IF EXISTS public.esia_cron_error OWNER to esia;

CREATE INDEX IF NOT EXISTS cron_index_plugin_id
    ON public.esia_cron_plugin USING btree
    (cron_plugin_id ASC NULLS LAST)
    TABLESPACE pg_default;

CREATE OR REPLACE FUNCTION public.trigger_notify_serviceCron()
    RETURNS trigger
    LANGUAGE 'plpgsql'
AS $BODY$
 DECLARE v_payload JSON;
BEGIN
	IF TG_OP = 'INSERT' THEN
		v_payload := json_build_object('TYPE','SERVICE','COMMAND','ADD','ID',NEW.cron_id);
	ELSEIF TG_OP = 'UPDATE' THEN
		v_payload := json_build_object('TYPE','SERVICE','COMMAND','UPDATE','ID',NEW.cron_id);
	END IF;
	PERFORM pg_notify('esiacronchannel',v_payload::text);
    RETURN NEW;
END;
$BODY$;
ALTER FUNCTION public.trigger_notify_serviceCron() OWNER TO esia;
CREATE TRIGGER "notifyCronDaemon"
    AFTER INSERT OR UPDATE
    ON public.esia_cron_plugin
    FOR EACH ROW
    EXECUTE FUNCTION public.trigger_notify_serviceCron();


ALTER TABLE IF EXISTS public.gesa_info  ADD COLUMN IF NOT EXISTS gesa_macadress macaddr;


-- Alerting by plugin
-- DROP TABLE IF EXISTS esia_plugin_react_program;
CREATE TABLE IF NOT EXISTS esia_plugin_react_program
(
    react_plugin_id integer NOT NULL,
    react_program_id integer NOT NULL,
    react_parameter character varying(150) COLLATE pg_catalog."default",
    react_ok boolean,
    react_warning boolean,
    react_critical boolean,
    react_unknown boolean,
    CONSTRAINT "esia_react_PrimaryKey" PRIMARY KEY (react_plugin_id, react_program_id),
    CONSTRAINT "esia_react_ForeignKey_program_id" FOREIGN KEY (react_program_id)
        REFERENCES esia_program (program_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION,
    CONSTRAINT "esia_react_ForeignKey_plugin_id" FOREIGN KEY (react_plugin_id)
        REFERENCES esia_plugins (plugin_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
);

ALTER TABLE IF EXISTS esia_plugin_react_program OWNER to esia;

-- Dashboard : lien rapide
INSERT INTO public.dashboard_view(
	view_id, view_name, view_file_path, view_during, view_default_height, view_default_width, view_default_option, view_group_id)
	VALUES (DEFAULT, 'DASHBOARD_FAST_LINK', '/dashboard/view_link.php?id=:widgetid', 30, 100, 300, '{"title":{"style":"text-align: center; font-size:15px;color:#575759;"},"description":{"style":"text-align: center; margin:auto;font-size:12px;"}}', NULL);


-- modfication pour ajouter la colone path

ALTER TABLE IF EXISTS public.esia_device_group  ADD COLUMN IF NOT EXISTS device_group_path text;

WITH RECURSIVE paths (device_group_id,name,path) AS (
	SELECT master.device_group_id, master.device_group_name, ARRAY[master.device_group_name]::character varying[] AS path
       FROM esia_device_group master
		WHERE device_group_id IN (SELECT device_group_id FROM esia_device_group WHERE device_group_parent IS NULL)
	UNION ALL
	SELECT sec.device_group_id, sec.device_group_name, paths.path || ARRAY[sec.device_group_name]
	 FROM esia_device_group sec
	 JOIN paths ON paths.device_group_id = sec.device_group_parent AND sec.device_group_name != ALL(paths.path)
)
UPDATE esia_device_group SET device_group_path=p.fullpath
FROM (select device_group_id,array_to_string(path,' > ')as fullpath from paths) as p
WHERE p.device_group_id = esia_device_group.device_group_id;


CREATE OR REPLACE FUNCTION public.gettopnodegroup(
	group_id integer)
    RETURNS esia_device_group
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE PARALLEL UNSAFE
AS $BODY$
	DECLARE
		v_row esia_device_group%ROWTYPE;
        BEGIN

		SELECT * INTO v_row
		FROM esia_device_group
		WHERE device_group_id = (SELECT device_group_parent FROM esia_device_group WHERE device_group_id=group_id);
		--Si le group_id est null c'est qu'on a demandé le top Group d'un group de top niveau (lvl1)
		IF v_row.device_group_id IS NULL
		THEN
			SELECT * INTO v_row FROM esia_device_group WHERE device_group_id=group_id;
			RETURN v_row;
		ELSE
			--Si le groupe parrent n'est pas null on est pas sur le top groupe
			IF v_row.device_group_parent IS NOT NULL
			THEN
				SELECT * INTO v_row  FROM getTopNodeGroup(v_row.device_group_id);
			END IF;
			RETURN v_row;
		END IF;


   END;
$BODY$;

ALTER FUNCTION public.gettopnodegroup(integer) OWNER TO esia;

CREATE OR REPLACE FUNCTION public.trigger_update_group_path()
    RETURNS trigger
    LANGUAGE 'plpgsql'
AS $BODY$
DECLARE
	v_var integer;
BEGIN
	--Si on est sur un top group
	v_var=0;
	IF NEW.device_group_parent IS NULL THEN
		UPDATE esia_device_group SET device_group_path = NEW.device_group_name WHERE device_group_id = NEW.device_group_id;
		v_var=1;
	END IF;
	IF v_var = 0 THEN
		--Si on est sur un top group
		WITH RECURSIVE paths (device_group_id,name,path) AS (
			SELECT master.device_group_id, master.device_group_name, ARRAY[master.device_group_path]::character varying[] AS path
       		FROM esia_device_group master
			WHERE device_group_id= (SELECT device_group_id FROM gettopnodegroup(NEW.device_group_id))
			UNION ALL
			SELECT sec.device_group_id, sec.device_group_name, paths.path || ARRAY[sec.device_group_name]
	 		FROM esia_device_group sec
	 		JOIN paths ON paths.device_group_id = sec.device_group_parent AND sec.device_group_name != ALL(paths.path)
		)
		UPDATE esia_device_group SET device_group_path=p.fullpath
		FROM (select device_group_id,array_to_string(path,' > ')as fullpath from paths) as p
		WHERE p.device_group_id = esia_device_group.device_group_id;
	END IF;
	IF TG_OP = 'UPDATE' THEN
		IF NEW.device_group_parent <> OLD.device_group_parent AND OLD.device_group_parent IS NOT NULL  THEN
		--Si on est sur un top group
		WITH RECURSIVE paths (device_group_id,name,path) AS (
			SELECT master.device_group_id, master.device_group_name, ARRAY[master.device_group_path]::character varying[] AS path
       		FROM esia_device_group master
			WHERE device_group_id= (SELECT device_group_id FROM gettopnodegroup(OLD.device_group_parent))
			UNION ALL
			SELECT sec.device_group_id, sec.device_group_name, paths.path || ARRAY[sec.device_group_name]
	 		FROM esia_device_group sec
	 		JOIN paths ON paths.device_group_id = sec.device_group_parent AND sec.device_group_name != ALL(paths.path)
		)
		UPDATE esia_device_group SET device_group_path=p.fullpath
		FROM (select device_group_id,array_to_string(path,' > ')as fullpath from paths) as p
		WHERE p.device_group_id = esia_device_group.device_group_id;
		END IF;
	END IF;
    RETURN NEW;
END;
$BODY$;
ALTER FUNCTION public.trigger_update_group_path() OWNER TO esia;
CREATE TRIGGER "updateGroupPath"
    AFTER INSERT OR UPDATE OF device_group_name, device_group_parent
    ON public.esia_device_group
    FOR EACH ROW
    EXECUTE FUNCTION public.trigger_update_group_path();

ALTER TABLE IF EXISTS public.dashboard ADD COLUMN IF NOT EXISTS dashboard_default boolean DEFAULT False;

CREATE TABLE IF NOT EXISTS public.rss_category
(
    category_id serial,
    category_name character varying(30) COLLATE pg_catalog."default",
    category_description text COLLATE pg_catalog."default",
    CONSTRAINT rss_category_pkey PRIMARY KEY (category_id)
);
ALTER TABLE IF EXISTS public.rss_category OWNER to esia;
CREATE TABLE IF NOT EXISTS public.rss_channel
(
    channel_id serial,
    channel_name character varying(50) COLLATE pg_catalog."default" NOT NULL,
    channel_description text COLLATE pg_catalog."default",
    channel_language character varying(10) COLLATE pg_catalog."default" DEFAULT 'fr-fr'::character varying,
    channel_last_publication timestamp with time zone,
    channel_image text COLLATE pg_catalog."default",
    channel_type character varying(10) COLLATE pg_catalog."default" DEFAULT 'LOCAL'::character varying,
    channel_url text COLLATE pg_catalog."default",
    channel_enable boolean NOT NULL DEFAULT true,
    channel_notdelete boolean DEFAULT false,
    CONSTRAINT rss_channel_pkey PRIMARY KEY (channel_id)
);
ALTER TABLE IF EXISTS public.rss_channel OWNER to esia;
CREATE TABLE IF NOT EXISTS public.rss_link_channel_to_category
(
    link_channel_id integer NOT NULL,
    link_category_id integer NOT NULL,
    CONSTRAINT rss_link_channel_to_category_pkey PRIMARY KEY (link_channel_id, link_category_id),
    CONSTRAINT "link_foreignKey_category_id" FOREIGN KEY (link_category_id)
        REFERENCES public.rss_category (category_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION,
    CONSTRAINT "link_foreignKey_channel_id" FOREIGN KEY (link_channel_id)
        REFERENCES public.rss_channel (channel_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
);
ALTER TABLE IF EXISTS public.rss_link_channel_to_category OWNER to esia;
CREATE TABLE IF NOT EXISTS public.rss_message
(
    message_id bigserial,
    message_title text COLLATE pg_catalog."default" NOT NULL,
    message_description text COLLATE pg_catalog."default",
    message_link text COLLATE pg_catalog."default",
    message_author character varying(50) COLLATE pg_catalog."default" NOT NULL,
    message_image text COLLATE pg_catalog."default",
    message_channel_id integer,
    message_sign character varying(64) COLLATE pg_catalog."default",
    message_date_publish timestamp with time zone,
    message_group_view integer[],
    message_categories character varying(100) COLLATE pg_catalog."default",
    CONSTRAINT rss_message_pkey PRIMARY KEY (message_id),
    CONSTRAINT "rss_message_foreignKey_channel" FOREIGN KEY (message_channel_id)
        REFERENCES public.rss_channel (channel_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
);

ALTER TABLE IF EXISTS public.rss_message OWNER to esia;

CREATE TABLE  IF NOT EXISTS public.rss_user_subscribe
(
    subscribe_user_id integer,
    subscribe_channel_id integer,
    CONSTRAINT "subscribe_primaryKey" PRIMARY KEY (subscribe_user_id, subscribe_channel_id),
    CONSTRAINT "subscribe_foreignKey_user" FOREIGN KEY (subscribe_user_id)
        REFERENCES public.esia_users (user_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
        NOT VALID,
    CONSTRAINT "subscribe_foreignKey_channel" FOREIGN KEY (subscribe_channel_id)
        REFERENCES public.rss_channel (channel_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
        NOT VALID
);

ALTER TABLE IF EXISTS public.rss_user_subscribe
    OWNER to esia;
ALTER TABLE IF EXISTS rss_channel ADD COLUMN channel_group_link text;


CREATE OR REPLACE FUNCTION public.trigger_channels()
    RETURNS trigger
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE NOT LEAKPROOF
AS $BODY$
DECLARE
	v_var  character varying[];
BEGIN
	raise notice 'TYPE %',TG_OP;
	IF TG_OP = 'UPDATE' THEN
		raise notice 'UPDATE % TO % ',OLD.channel_group_link,NEW.channel_group_link;
		IF NEW.channel_group_link <> OLD.channel_group_link OR NEW.channel_group_link IS NULL
		THEN
			raise notice 'DELETE OLD ';
			DELETE FROM rss_user_subscribe WHERE subscribe_channel_id= NEW.channel_id;
		END IF;
	END IF;
	IF NEW.channel_group_link <> OLD.channel_group_link OR  NEW.channel_group_link IS NOT NULL
	THEN
		IF NEW.channel_group_link = 'RSS_GROUP_ALL'
		THEN
			INSERT INTO rss_user_subscribe(subscribe_user_id, subscribe_channel_id)
			SELECT user_id,NEW.channel_id
			FROM esia_users
			ON CONFLICT ON CONSTRAINT "subscribe_primaryKey" DO NOTHING;
		ELSE
			v_var = string_to_array(NEW.channel_group_link,',');
			INSERT INTO rss_user_subscribe(subscribe_user_id, subscribe_channel_id)
			SELECT user_id,NEW.channel_id
			FROM esia_users
			JOIN esia_memberof ON user_id = member_user_id
			JOIN esia_groups ON group_id = member_group_id
			WHERE group_name = ANY(v_var)
			ON CONFLICT ON CONSTRAINT "subscribe_primaryKey" DO NOTHING;
		END IF;
	END IF;
    RETURN NEW;
END;
$BODY$;

ALTER FUNCTION public.trigger_channels() OWNER TO esia;

CREATE TRIGGER trigger_channels
    AFTER INSERT OR UPDATE OF channel_group_link
    ON public.rss_channel
    FOR EACH ROW
    EXECUTE FUNCTION public.trigger_channels();


CREATE OR REPLACE FUNCTION public.trigger_insert_update_memberof()
    RETURNS trigger
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE NOT LEAKPROOF
AS $BODY$
DECLARE
BEGIN
	INSERT INTO rss_user_subscribe(subscribe_user_id, subscribe_channel_id)
	SELECT NEW.member_user_id,channel_id
	FROM rss_channel AS chan
	WHERE EXISTS (
		SELECT *
		FROM unnest(string_to_array(chan.channel_group_link,',')) AS elem(usergroup)
		WHERE usergroup IN (
			SELECT group_name
			FROM esia_groups
			WHERE group_id= NEW.member_group_id
			)
	)
	UNION
	SELECT NEW.member_user_id,channel_id
	FROM rss_channel
	WHERE channel_group_link='RSS_GROUP_ALL'
	ON CONFLICT ON CONSTRAINT "subscribe_primaryKey" DO NOTHING;
    RETURN NEW;
END;
$BODY$;

ALTER FUNCTION public.trigger_insert_update_memberof() OWNER TO esia;

CREATE TRIGGER trigger_memberof
    AFTER INSERT OR UPDATE
    ON public.esia_memberof
    FOR EACH ROW
    EXECUTE FUNCTION public.trigger_insert_update_memberof();

 CREATE TABLE IF NOT EXISTS public.rss_user_read
(
    read_user_id integer NOT NULL,
    read_message_id bigint NOT NULL,
    CONSTRAINT "read_primaryKey" PRIMARY KEY (read_user_id, read_message_id),
    CONSTRAINT "read_foreignKey_message_id" FOREIGN KEY (read_message_id)
        REFERENCES public.rss_message (message_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION,
    CONSTRAINT "read_foreignKey_user_id" FOREIGN KEY (read_user_id)
        REFERENCES public.esia_users (user_id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
);

ALTER TABLE IF EXISTS public.rss_user_read OWNER to esia;

INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Watchguard - endpoint', '', '', NULL, '', 'REMOTE', 'https://www.watchguard.com/wgrd-blog/feed/endpoint-security', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Axis - Firmware', '', '', NULL, '', 'REMOTE', 'http://feeds.axis.com/axisfirmware', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Qnap - News', '', '', NULL, '', 'REMOTE', 'https://www.qnap.com/fr-fr/news/feed', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Pfsense - News', '', '', NULL, '', 'REMOTE', 'https://www.netgate.com/blog/rss.xml', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Cisco - security', '', '', NULL, '', 'REMOTE', 'https://sec.cloudapps.cisco.com/security/center/psirtrss20/CiscoSecurityAdvisory.xml', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Synology - News', '', '', NULL, '', 'REMOTE', 'https://www.synology.com/api/rssfeed/news/en-global', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Proxmox', '', '', NULL, '', 'REMOTE', 'https://my.proxmox.com/en/announcements/rss', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Zyxel - USG', '', '', NULL, '', 'REMOTE', 'https://community.zyxel.com/en/categories/security-gateway-news-and-release/feed.rss', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Stormshield - security', '', '', NULL, '', 'REMOTE', 'https://advisories.stormshield.eu/feed/', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'OPNSense', '', '', NULL, '', 'REMOTE', 'https://forum.opnsense.org/index.php?board=11.0;type=rss;action=.xml', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Ubuntu - News', '', '', NULL, '', 'REMOTE', 'https://ubuntu-news.org/feed/', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Microsoft - security', '', '', NULL, '', 'REMOTE', 'https://api.msrc.microsoft.com/update-guide/rss', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'APC - News', '', '', NULL, '', 'REMOTE', 'https://blog.apc.com/category/solutions-services/feed/', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'HPE - News', '', '', NULL, '', 'REMOTE', 'https://www.hpe.com/us/en/newsroom/rss.xml', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Citrix - security', '', '', NULL, '', 'REMOTE', 'https://support.citrix.com/feed/products/all/securitybulletins.rss', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'RedHat - security', '', '', NULL, '', 'REMOTE', 'https://www.redhat.com/en/rss/blog/channel/security', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Debian - News', '', '', NULL, '', 'REMOTE', 'https://www.debian.org/News/news', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Redhat - Enterprise', '', '', NULL, '', 'REMOTE', 'https://www.redhat.com/en/rss/blog/channel/red-hat-enterprise-linux', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Sophos - UTM', '', '', NULL, '', 'REMOTE', 'https://community.sophos.com/utm-firewall/b/blog/rss', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Sophos - XG', '', '', NULL, '', 'REMOTE', 'https://community.sophos.com/sophos-xg-firewall/b/blog/rss', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Fortinet - PSIRT', '', '', NULL, '', 'REMOTE', 'https://feeds.fortinet.com/fortinet/blog/psirt&x=1', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Dell - Product', '', '', NULL, '', 'REMOTE', 'https://www.dell.com/en-us/blog/categories/products/feed/', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Sophos - produit', '', '', NULL, '', 'REMOTE', 'https://news.sophos.com/fr-fr/category/products-services/feed', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Citrix - Software', '', '', NULL, '', 'REMOTE', 'https://support.citrix.com/feed/products/all/softwareupdates.rss', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'VMware - VSphere', '', '', NULL, '', 'REMOTE', 'https://docs.vmware.com/en/VMware-vSphere/rn_rss.xml', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Fortinet - Firmware', '', '', NULL, '', 'REMOTE', 'https://pub.kb.fortinet.com/rss/firmware.xml', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Riello UPS- News', '', '', NULL, '', 'REMOTE', 'https://www.riello-ups.fr/feed', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Fortinet - security', '', '', NULL, '', 'REMOTE', 'https://filestore.fortinet.com/fortiguard/rss/ir.xml', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Watchguard - network', '', '', NULL, '', 'REMOTE', 'https://www.watchguard.com/wgrd-blog/feed/network-security', false, false, NULL) ON CONFLICT DO NOTHING;
INSERT INTO public.rss_channel (channel_id, channel_name, channel_description, channel_language, channel_last_publication, channel_image, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link) VALUES (DEFAULT, 'Debian - security', '', '', NULL, '', 'REMOTE', 'https://www.debian.org/security/dsa-long', false, false, NULL) ON CONFLICT DO NOTHING;

INSERT INTO esia_plugins(plugin_id, plugin_name, plugin_path,plugin_type,plugin_default_interval_time, plugin_description, plugin_priority, plugin_manufacturer,plugin_tag, plugin_cron_type, plugin_cron_only_existing)	VALUES (DEFAULT,'CRON_RSS_SYNCHRONIZATION','/usr/local/esia/public_html/cron/sync-rss.php','cron',3600000,'Synchronisation des flux RSS',5,'ESIA','ESIA,RSS,CRON','minut', true);
INSERT INTO public.esia_cron_plugin(
	cron_id, cron_plugin_id, cron_interval, cron_next_exec, cron_log_file, cron_retries, cron_retries_interval)
	VALUES (DEFAULT, (SELECT plugin_id FROM esia_plugins WHERE plugin_name='CRON_RSS_SYNCHRONIZATION') ,'30 minute'::interval, NOW()+interval '15 minute','rss_$SERVICEID_$DATE.log',1,'1 minute'::interval);

INSERT INTO public.esia_configuration(config_key, config_value, config_description, config_type, config_visibility)	VALUES ('RSS_PURGE_MESSAGE',60,'Purge automatique des message RSS','integer',true);
INSERT INTO public.dashboard_widget_group(widget_group_id, widget_group_name, widget_group_order)	VALUES (DEFAULT,'ESIA_CRON', 75);
INSERT INTO public.dashboard_view(
	view_id, view_name, view_file_path, view_during, view_default_height, view_default_width, view_default_option, view_group_id)
	VALUES (DEFAULT, 'DASHBOARD_CRON_ERROR', '/dashboard/view_cron_error.php?id=:widgetid', 30, 100, 300, '{"title":{"style":"text-align: center; font-size:15px;color:#575759;"},"description":{"style":"text-align: center; margin:auto;font-size:12px; color:#575759"},"table":{"class":"arraytop","style":"width:60%; height:60%; margin: auto; border-spacing: 10px 10px;"},"td":{"style":"font-size:50px;"}}', (SELECT widget_group_id FROM dashboard_widget_group WHERE widget_group_name='ESIA_CRON'));


INSERT INTO public.dashboard_view(
	view_id, view_name, view_file_path, view_during, view_default_height, view_default_width, view_default_option, view_group_id)
	VALUES (DEFAULT, 'DASHBOARD_CRON_STATE', '/dashboard/view_cron_4state.php?id=:widgetid', 30, 100, 300, '{"title":{"style":"text-align: center; font-size:15px;color:#575759;"},"description":{"style":"text-align: center; margin:auto;font-size:12px; color:#575759;"},"table":{"class":"arraytop","style":"width:60%; height:60%; margin: auto; border-spacing: 10px 10px;"},"td":{"style":"font-size:50px;"},"type":"table","unknown":"unknown","blink":"none"}', (SELECT widget_group_id FROM dashboard_widget_group WHERE widget_group_name='ESIA_CRON'));



INSERT INTO dashboard(dashboard_id, dashboard_name, dashboard_controller, dashboard_default)
	VALUES (DEFAULT,'LANG_DASHBOARD_HOME_NEW','/dashboard/default.php?id=:dashid',true);

INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,0,280,19.395322304621,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW') );
INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,1,280,18.539646320593,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW') );
INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,2,280,20.136908157444,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW') );
INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,3,280,17.683970336566,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW') );
INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,4,280,18.026240730177,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW') );
INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,5,650,41.414717626925,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW') );
INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,6,650,23.103251568739,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW') );
INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,7,650,30.347974900171,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW') );

INSERT INTO dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option,widget_description, widget_tile_id, widget_view_id)
VALUES (DEFAULT, 'LANG_DASHBOARD_DEFAULT_SERVICE_STATUS', 30, NULL, '{"title":{"style":"text-align: left; font-size:15px;color:#575759;"},"description":{"style":"text-align: left; margin:auto;font-size:12px; color:#575759"},"table":{"class":"arraytop","style":"width:60%; height:60%; margin: auto; border-spacing: 10px 10px;"},"td":{"style":"font-size:50px;"},"type":"pie","service":[],"show_unknown":"unknown","show_pending":"pending","blink":"none","service_or_node":"service","all_service":"on","all_node":""}', 'LANG_DASHBOARD_DEFAULT_SERVICE_STATUS_DESCR',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=0 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_SERV_STATE'));

INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option,widget_description, widget_tile_id, widget_view_id) VALUES (DEFAULT, 'LANG_DASHBOARD_DEFAULT_ESIA_STATUS', 30, NULL, '{"title":{"style":"text-align: left; font-size:15px;color:#575759;"},"description":{"style":"text-align: left; margin:auto;font-size:12px; color:#575759"},"table":{"class":"arraytop","style":"width:60%; height:60%; margin: auto; border-spacing: 10px 10px;"},"td":{"style":"font-size:50px;"},"type":"table","nodeid":["1"],"show_unknown":"unknown","show_pending":"pending","blink":"none","service_or_node":null,"all_service":"","all_node":""}','LANG_DASHBOARD_DEFAULT_ESIA_STATUS_DESCR',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=1 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_NODE_STATE'));


INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option, widget_description, widget_tile_id, widget_view_id) VALUES (DEFAULT, 'LANG_DASHBOARD_CRON', 30, NULL, '{"title":{"style":"text-align: left; font-size:15px;color:#575759;"},"description":{"style":"text-align: left; margin:auto;font-size:12px; color:#575759;"},"table":{"class":"arraytop","style":"width:60%; height:60%; margin: auto; border-spacing: 10px 10px;"},"td":{"style":"font-size:50px;"},"type":"ring","unknown":"unknown","blink":"none","interval":"1","line":"2"}','LANG_DASHBOARD_CRON_DESC',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=2 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_CRON_STATE'));

INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option, widget_tile_id, widget_view_id) VALUES (DEFAULT, 'LANG_DASHBOARD_RSS_NOREAD_MSG', 30, NULL, '{"message_id":"","title":{"style":"text-align: left; font-size:14px; color:#575759"},"description":{"style":"text-align: left; font-size:12px; color:#575759"},"list_channel":["0"],"list_category":["0"],"filter":"chan","type":null,"affiche_msg":"show_msg_view","showchannel":"on","showmessage":null,"showdate":"on","showauthor":null}',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=3 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_MESSAGE'));

INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option, widget_tile_id, widget_view_id) VALUES (DEFAULT, 'LANG_DASHBOARD_FAST_LINK', 30, NULL, '{"title":{"style":"text-align: left; font-size:14px;color:#575759;"},"description":{"style":"text-align: left; margin:auto;font-size:12px; color:#575759"},"link":[{"text":"\/administration.php","icon":"node","label":"LANG_DAHSBOARD_LINK_ADMINISTRATION"},{"text":"\/plugin\/importation\/import_control.php","icon":"scanner","label":"LANG_DAHSBOARD_LINK_NETSCAN"},{"text":"https:\/\/wiki.esia-sa.com\/","icon":"wiki","label":"LANG_WIKI"},{"text":"https:\/\/wiki.esia-sa.com\/faq","icon":"faq","label":"LANG_FAQ"},{"text":"https:\/\/wiki.esia-sa.com\/mobile","icon":"esia voyager","label":"LANG_ESIAVOYAGER"},{"text":"\/rss_view.php","icon":"rss","label":"LANG_RSS_FLOW"}]}',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=4 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_FAST_LINK'));

INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option, widget_tile_id, widget_view_id) VALUES (DEFAULT, 'LANG_DASHBOARD_DEFAULT_CURRENT_ALERT', 30, NULL, '{"title":{"style":"text-align: center; font-size:14px; color:#575759;"},"description":{"style":"text-align: left; margin:auto;font-size:12px; color:#575759"},"table":{"class":"arraytop","style":"width:60%; height:60%; margin: auto; border-spacing: 10px 10px;"},"td":{"style":"font-size:50px;"},"filters":{"node":"","ip":"","description":"","group":"","alert":"!maintenance","service":""},"column":{"group":1,"descr":0,"ip":0,"message":0,"date":0},"hierarch":true}',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=5 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_ALARM'));

INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option, widget_description, widget_tile_id, widget_view_id) VALUES (DEFAULT, 'LANG_DASHBOARD_DEFAULT_TOP', 30, NULL, '{"title":{"style":"text-align: left; font-size:15px; color:#575759;"},"description":{"style":"text-align: left; margin:auto;font-size:12px; color:#575759"},"table":{"class":"arraytop","style":"width:60%; height:60%; margin: auto; border-spacing: 10px 10px;"},"td":{"style":"font-size:50px;"},"interval":"1","limit":"10","type":null}', 'LANG_DASHBOARD_DEFAULT_TOP_DESCR',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=6 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_TOP_NODE_ERROR'));


INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option, widget_tile_id, widget_view_id) VALUES (DEFAULT, 'LANG_DASHBOARD_RSS_ESIA_MSG', 30, NULL, '{"message_id":"","title":{"style":"text-align: left; font-size:14px; color:#575759"},"description":{"style":"text-align: left; font-size:12px; color:#575759"},"list_channel":[],"list_category":[],"filter":"cat","type":null,"affiche_msg":"show_tab_view","showchannel":"on","showmessage":null,"showdate":"on","showauthor":null}',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=7 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_MESSAGE'));



INSERT INTO dashboard(dashboard_id, dashboard_name, dashboard_controller, dashboard_default)
VALUES (DEFAULT,'LANG_DASHBOARD_HOME_NEW_OLD','/dashboard/default.php?id=:dashid',true);


INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,0,250,20.788302606484,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW_OLD') );
INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,1,250,22.314049586777,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW_OLD') );
INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,2,250,18.054672600127,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW_OLD') );
INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,3,250,32.422123331214,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW_OLD') );
INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,4,550,62.301335028608,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW_OLD') );
INSERT INTO public.dashboard_tile(tile_id, tile_position, tile_height, tile_width, tile_dashboard_id)
	VALUES (DEFAULT,5,550,32.48569612206,(SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW_OLD') );

INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option, widget_description, widget_tile_id, widget_view_id) VALUES (DEFAULT, 'LANG_DASHBOARD_DEFAULT_SERVICE_STATUS', 30, NULL, '{"title":{"style":"text-align: left; font-size:15px;color:#575759;"},"description":{"style":"text-align: left; margin:auto;font-size:12px; color:#575759"},"table":{"class":"arraytop","style":"width:60%; height:60%; margin: auto; border-spacing: 10px 10px;"},"td":{"style":"font-size:50px;"},"type":"pie","service":[],"show_unknown":"unknown","show_pending":"pending","blink":"none","service_or_node":"service","all_service":"on","all_node":""}','LANG_DASHBOARD_DEFAULT_SERVICE_STATUS_DESCR',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=0 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW_OLD')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_SERV_STATE'));


INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option, widget_description, widget_tile_id, widget_view_id) VALUES (DEFAULT,
'LANG_DASHBOARD_DEFAULT_ESIA_STATUS', 30, NULL, '{"title":{"style":"text-align: left; font-size:15px;color:#575759;"},"description":{"style":"text-align: left; margin:auto;font-size:12px; color:#575759"},"table":{"class":"arraytop","style":"width:60%; height:60%; margin: auto; border-spacing: 10px 10px;"},"td":{"style":"font-size:50px;"},"type":"table","nodeid":["1"],"show_unknown":"unknown","show_pending":"pending","blink":"none","service_or_node":null,"all_service":"","all_node":""}', 'LANG_DASHBOARD_DEFAULT_ESIA_STATUS_DESCR',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=1 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW_OLD')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_NODE_STATE'));


INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option, widget_description, widget_tile_id, widget_view_id) VALUES (DEFAULT,
'LANG_ADMIN', 30, NULL, '{"title":{"style":"text-align: left; font-size:14px;color:#575759;"},"description":{"style":"text-align: left; margin:auto;font-size:12px; color:#575759"},"link":[{"text":"\/administration.php","icon":"node","label":"LANG_ADM_LIST_DEV"},{"text":"\/administration.php?tab=nodegroups","icon":"nodegroup","label":"LANG_ADM_NODE_GROUP"},{"text":"\/administration.php?tab=usergroups","icon":"group","label":"LANG_DASHBOARD_USER_GROUP_MAN"},{"text":"\/administration.php?tab=plugins","icon":"plugin","label":"LANG_PLUGINS"},{"text":"\/plugin\/importation\/import_control.php","icon":"scanner","label":"LANG_DAHSBOARD_LINK_NETSCAN"}]}','',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=2 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW_OLD')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_FAST_LINK'));

INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option, widget_description, widget_tile_id, widget_view_id) VALUES (DEFAULT,
'LANG_HELP', 30, NULL, '{"title":{"style":"text-align: left; font-size:14px;color:#575759;"},"description":{"style":"text-align: left; margin:auto;font-size:12px; color:#575759"},"link":[{"text":"https:\/\/wiki.esia-sa.com\/","icon":"wiki","label":"LANG_WIKI"},{"text":"https:\/\/wiki.esia-sa.com\/faq","icon":"faq","label":"LANG_FAQ"},{"text":"https:\/\/wiki.esia-sa.com\/mobile","icon":"esia voyager","label":"LANG_ESIAVOYAGER"},{"text":"\/rss_view.php","icon":"rss","label":"LANG_RSS_FLOW"},{"text":"https:\/\/wiki.esia-sa.com\/advanced\/config_ip_unity","icon":"unity","label":"LANG_DASHBOARD_UNITY_CONFIG"}]}','',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=3 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW_OLD')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_FAST_LINK'));

INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option, widget_description, widget_tile_id, widget_view_id) VALUES (DEFAULT,
'LANG_DASHBOARD_NODE_TYPE_TAB', 30, NULL, '{"title":{"style":"text-align: left; font-size:14px;color:#575759;"},"description":{"style":"text-align: left; margin:auto;font-size:12px; color:#575759"},"table":{"class":"arraytop","style":"width:60%; height:60%; margin: auto; border-spacing: 10px 10px;"},"td":{"style":"font-size:50px;"},"type":"table","warning":1,"critical":1,"unknown":1,"statusonly":0,"order":[],"nbr_service":1,"nbr_device":1}','',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=4 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW_OLD')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_NODE_TYPE_TAB'));

INSERT INTO public.dashboard_widget (widget_id, widget_name, widget_view_during, widget_position, widget_option, widget_description, widget_tile_id, widget_view_id) VALUES (DEFAULT,
 'LANG_DASHBOARD_RSS_ESIA_MSG', 30, NULL, '{"message_id":"","title":{"style":"text-align: left; font-size:14px; color:#575759"},"description":{"style":"text-align: left; font-size:12px; color:#575759"},"list_channel":[],"list_category":[],"filter":"cat","type":null,"affiche_msg":"show_tab_view","showchannel":"on","showmessage":null,"showdate":"on","showauthor":null}','',
(SELECT tile_id FROM dashboard_tile WHERE tile_position=5 AND tile_dashboard_id IN (SELECT dashboard_id FROM dashboard WHERE dashboard_name='LANG_DASHBOARD_HOME_NEW_OLD')),
(SELECT view_id FROM dashboard_view WHERE view_name='DASHBOARD_MESSAGE'));
INSERT INTO public.esia_configuration(config_key, config_value, config_type, config_visibility)	VALUES ('LICENCE_EGIDE',NULL,'text',false);
INSERT INTO public.esia_configuration(config_key, config_value, config_description, config_type, config_visibility)	VALUES ('ESIA_URL','localhost','FQDN du serveur ESIA','string',true);


INSERT INTO public.rss_channel(channel_id, channel_name, channel_description, channel_language, channel_type, channel_url, channel_enable, channel_notdelete, channel_group_link)
VALUES (DEFAULT,'Esia - News',NULL,'fr-be','REMOTE','https://rss.esia-sa.com/rss.php?flow=ESIA+-+NEWS',true,true,'RSS_GROUP_ALL');
